@@ -12,8 +12,10 @@ generate_meta_package() {
     [ -r $1 ] || die "Can't find $1 ."
     dpkg-deb -x $1 tmp
     dpkg-deb -e $1 tmp/DEBIAN
-    dir=`echo -n tmp/usr/share/doc/*`
-    mv ${dir} ${dir}-ccs
+    for dir in tmp/usr/share/doc/* tmp/usr/share/bug/*
+    do
+	mv ${dir} ${dir}-ccs
+    done
     sed -i -e 's:-686:-686-ccs:' -- tmp/DEBIAN/md5sums tmp/DEBIAN/control
     dpkg-deb -b tmp && mv tmp.deb $2
     rm -fR tmp
@@ -26,27 +28,26 @@ apt-get -y install wget zlib1g-dev debian-keyring
 # Download TOMOYO Linux patches.
 mkdir -p /root/rpmbuild/SOURCES/
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.1-20110401.tar.gz ]
+if [ ! -r ccs-patch-1.8.2-20110626.tar.gz ]
 then
-    wget -O ccs-patch-1.8.1-20110401.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.1-20110401.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.2-20110626.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.2-20110626.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
 cd /usr/src/ || die "Can't chdir to /usr/src/ ."
-apt-get install fakeroot build-essential || die "Can't install packages."
-apt-get build-dep linux-image-2.6.32-5-686 || die "Can't install packages."
-apt-get source linux-image-2.6.32-5-686 || die "Can't install kernel source."
+apt-get install build-essential kernel-package || die "Can't install packages."
+apt-get install linux-source-2.6.32 || die "Can't install kernel source."
+rm -fR linux-source-2.6.32
+tar -jxf linux-source-2.6.32.tar.bz2
 
 # Apply patches and create kernel config.
-cd linux-2.6-2.6.32 || die "Can't chdir to linux-2.6-2.6.32/ ."
-tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.1-20110401.tar.gz || die "Can't extract patch."
+cd linux-source-2.6.32 || die "Can't chdir to linux-source-2.6.18/ ."
+tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.2-20110626.tar.gz || die "Can't extract patch."
 patch -p1 < patches/ccs-patch-2.6.32-debian-squeeze.diff || die "Can't apply patch."
 cat /boot/config-2.6.32-5-686 config.ccs > .config || die "Can't create config."
-make -s oldconfig
 
 # Start compilation.
-REVISION=`head -n 1 debian/changelog | awk ' { print $2 } ' | awk -F'(' ' { print $2 } ' |  awk -F')' ' { print $1 } '`
-make-kpkg --append-to-version -5-686-ccs --initrd --revision $REVISION linux-image || die "Failed to build kernel package."
+make-kpkg --append-to-version -5-686-ccs --revision `sed -e 's/ /-/' version.Debian` --initrd binary-arch || die "Failed to build kernel package."
 
 # Generate meta packages.
 wget http://ftp.jp.debian.org/debian/pool/main/l/linux-latest-2.6/linux-image-2.6-686_2.6.32+29_i386.deb
