@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for openSUSE 11.1's 2.6.27 kernel.
+# This is a kernel build script for openSUSE 11.0's 2.6.25 kernel.
 #
 
 die () {
@@ -60,17 +60,17 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-2.6.27.56-0.1.1.src.rpm ]
+if [ ! -r kernel-source-2.6.25.20-0.7.src.rpm ]
 then
-    wget http://download.opensuse.org/update/11.1/rpm/src/kernel-source-2.6.27.56-0.1.1.src.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.0/rpm/src/kernel-source-2.6.25.20-0.7.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-source-2.6.27.56-0.1.1.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-source-2.6.27.56-0.1.1.src.rpm || die "Can't install source package."
+rpm --checksig kernel-source-2.6.25.20-0.7.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-source-2.6.25.20-0.7.src.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.2-20110620.tar.gz ]
+if [ ! -r ccs-patch-1.8.2-20110626.tar.gz ]
 then
-    wget -O ccs-patch-1.8.2-20110620.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.2-20110620.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.2-20110626.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.2-20110626.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -78,49 +78,32 @@ cp -p /usr/src/packages/SOURCES/kernel-default.spec . || die "Can't copy spec fi
 patch << "EOF" || die "Can't patch spec file."
 --- kernel-default.spec
 +++ kernel-default.spec
-@@ -63,13 +63,13 @@
- %if %build_vanilla || %build_kdump || %CONFIG_MODULES != "y"
- %define split_packages 0
- %else
--%define split_packages 1
-+%define split_packages 0
+@@ -49,10 +49,10 @@
+ %define build_nomodules 1
  %endif
  
 -Name:           kernel-default
 +Name:           ccs-kernel-default
- Summary:        The Standard Kernel
- Version:        2.6.27.56
--Release:        0.1.1
-+Release:        0.1.1_tomoyo_1.8.2
- License:        GPL v2 only
+ Summary:        The Standard Kernel for both Uniprocessor and Multiprocessor Systems
+ Version:        2.6.25.20
+-Release: 0.7
++Release: 0.7_tomoyo_1.8.2
+ License:        GPL v2 or later
  Group:          System/Kernel
  Url:            http://www.kernel.org/
-@@ -342,6 +342,10 @@
+@@ -343,6 +343,10 @@
  source .rpm-defs
  
- cd linux-2.6.27
+ cd linux-2.6.25
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.2-20110620.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.27-suse-11.1.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.2-20110626.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.25-suse-11.0.diff
 +cat config.ccs >> .config
  cp .config .config.orig
  %if %{tolerate_unknown_new_config_options}
  MAKE_ARGS="$MAKE_ARGS -k"
 EOF
-patch << "EOF" || die "Can't patch spec file."
---- kernel-default.spec
-+++ kernel-default.spec
-@@ -97,7 +97,7 @@
- #!BuildIgnore:  perl-Bootloader mkinitrd
- 
- %if ! 0%{?opensuse_bs}
--BuildRequires:  kernel-dummy
-+#BuildRequires:  kernel-dummy
- %endif
- %ifarch ia64
- # arch/ia64/scripts/unwcheck.py
-EOF
-sed -e 's:^Provides:#Provides:' -e 's:^Obsoletes:#Obsoletes:' -e 's:-n kernel:-n ccs-kernel:' kernel-default.spec > ccs-kernel.spec || die "Can't edit spec file."
+sed -e 's:^Provides:#Provides:' -e 's:^Obsoletes:#Obsoletes:' kernel-default.spec > ccs-kernel.spec || die "Can't edit spec file."
 echo ""
 echo ""
 echo ""
